import {Request, Response} from 'express';
import {reportError} from '../../../core/utils';
import {knex} from '../../../models';

export default async (req: Request, res: Response) => {
    try {
        const result = await knex.raw(`
            SELECT name, title, rating
            FROM wikidot_pages wp1
            WHERE name ~ '^scp-[0-9]{3,4}$' AND wiki_name = 'scp-wiki'
                AND NOT EXISTS(SELECT 1
                               FROM wikidot_pages wp2
                               WHERE wp2.wiki_name = 'scp-ru' AND wp2.name = wp1.name)
            ORDER BY rating DESC;
        `);
        res.send(result.rows);
    } catch (error) {
        res.status(500).send('Unhandled internal error, incident reported');
        reportError(error, {tags: {location: 'api/untranslated-list'}});
    }
};
