'use strict';

import {Branch} from '../models';
import {log, reportError} from '../core/utils';
import {wk} from '../components/wikidot-kit';

module.exports = async function run(): Promise<void> {
    log('Performing pages lists import');

    const branches = await Branch.query();

    await Promise.all(branches.map(async (branch: Branch) => {
        const name = branch.name;
        try {
            const pagesList = await wk.fetchPagesList(name);
            await Branch
                .query()
                .patch({pagesList})
                .where({name});
            log(`Pages list for wiki ${name} updated`);
        } catch (error) {
            reportError(error, {extra: {name}});
        }
    }));
    log('Pages list for all wikis updated');
};
