"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../../core/utils");
const models_1 = require("../../models");
let pages = {};
async function updatePagesRegistry() {
    const branches = await models_1.Branch.query().where({ interwiki: true });
    pages = {};
    branches.forEach((branch) => {
        const wiki = branch.name;
        branch.pagesList.forEach((pageName) => {
            if (pages[pageName]) {
                pages[pageName].push(wiki);
            }
            else {
                pages[pageName] = [wiki];
            }
        });
    });
    setTimeout(() => {
        initPagedRegistryUpdate();
    }, 1000 * 60 * 30); // 30 min
}
function initPagedRegistryUpdate() {
    updatePagesRegistry().then(() => {
        utils_1.log('InterWiki page registry updated');
    }).catch(error => {
        utils_1.reportError(error, { message: 'Error occured during pages list registry update' });
    });
}
initPagedRegistryUpdate();
function getWikiListByPageName(name) {
    return pages[name] || [];
}
exports.default = getWikiListByPageName;
//# sourceMappingURL=registry.js.map