"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const pino = require("pino");
const Sentry = require("raven");
const redisLib = require("redis");
const queues_1 = require("../components/queues");
const redis = redisLib.createClient();
const SENTRY_DSN = process.env.SENTRY_DSN;
Sentry.config(SENTRY_DSN).install();
exports.sentry = Sentry;
exports.logger = pino();
function log(message, args) {
    if (args) {
        exports.logger.info(args, message);
    }
    else {
        exports.logger.info(message);
    }
}
exports.log = log;
function reportError(error, args) {
    const callArgs = [error];
    if (args) {
        if (args.message) {
            callArgs.push(args.message);
        }
        if (args.extra) {
            callArgs.push(args.extra);
        }
    }
    exports.logger.error.apply(pino, callArgs);
    exports.sentry.captureException(error, args);
}
exports.reportError = reportError;
function logToDiscord(message) {
    log(`[DiscordLogger] ${message}`);
    redis.publish('discordLog', message);
}
exports.logToDiscord = logToDiscord;
function enqueue(task, args, queue = 'common') {
    return queues_1.default[queue].add({ task, args });
}
exports.enqueue = enqueue;
function clearNulls(input) {
    return Object.keys(input).reduce((acc, current) => {
        if (input[current] !== null) {
            acc[current] = input[current];
        }
        return acc;
    }, {});
}
exports.clearNulls = clearNulls;
//# sourceMappingURL=utils.js.map