'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../core/utils");
const trello_1 = require("../components/trello");
const models_1 = require("../models");
const wikidot_kit_1 = require("../components/wikidot-kit");
const PAGE_NAME_REG = /^[a-zA-Z0-9_:-]+$/;
const FEATURED_BLOCK_REGEXP = /\[!--\sFEATURED_DAILY_START\s--][\s\S]*\[!--\sFEATURED_DAILY_END\s--]/;
const WIKI_NAME = 'scp-ru';
const PAGE_NAME = '_default:main';
module.exports = async function run() {
    const previousCards = (await trello_1.getListCards(trello_1.DAILY_PREVIOUS_LIST_ID)).slice(0, 3);
    const backlogCards = await trello_1.getListCards(trello_1.DAILY_BACKLOG_LIST_ID);
    const current = backlogCards[0];
    if (!current) {
        throw new Error('Featured Daily Queue is empty');
    }
    const name = current.name;
    if (!PAGE_NAME_REG.test(name)) {
        throw new Error(`Featured Daily page name is not valid ("${name}")`);
    }
    utils_1.log(`Rotating featured daily page to ${name}`);
    const currentPage = await models_1.WikidotPage.query().where({ wikiName: WIKI_NAME, name }).first();
    const previousPages = await Promise.all(previousCards.map(async ({ name: cardName }) => models_1.WikidotPage.query().where({ wikiName: WIKI_NAME, name: cardName }).first()));
    const previousPagesLinks = previousPages.map(page => `- [/${page.name} ${page.title}]`).join('\n');
    const updatedBlock = `
[!-- FEATURED_DAILY_START --]
[[div class="scp-featured__block scp-featured__block_type_daily"]]
  [[div class="scp-featured__title"]]
    Объект дня
  [[/div]]
  [[div class="scp-featured__page-title"]]
    [/${currentPage.name} ${currentPage.title}]
  [[/div]]
  [[div class="scp-featured__content"]]
  [[/div]]

  [[div class="scp-featured__previous"]]
    [[span class="scp-featured__previous-title"]]Предыдущие дни:[[/span]]
      ${previousPagesLinks}
  [[/div]]
[[/div]]
[!-- FEATURED_DAILY_END --]
    `.trim();
    const content = (await wikidot_kit_1.wk.call(WIKI_NAME, 'pages.get_one', { page: PAGE_NAME })).content;
    const updatedContent = content.replace(FEATURED_BLOCK_REGEXP, updatedBlock);
    await wikidot_kit_1.wk.call(WIKI_NAME, 'pages.save_one', {
        page: PAGE_NAME,
        content: updatedContent
    });
    await trello_1.updateCardList(current.id, trello_1.DAILY_PREVIOUS_LIST_ID, (previousCards[0] && previousCards[0].pos - 1));
    utils_1.logToDiscord(`Successfully rotated featured daily page to ${name}`);
};
//# sourceMappingURL=featured-daily-rotation.js.map